#ifndef _TRIGUTIL_H_
#define _TRIGUTIL_H_

/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \----------------------------------------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      ** 
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       ** 
**   FROG: [hep-ex/0901.2718v1]                                       **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           ** 
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         ** 
**                                                                    ** 
**         Center for Particle Physics and Phenomenology (CP3)        ** 
**                Universite catholique de Louvain (UCL)              **       
**                     Louvain-la-Neuve, Belgium                      **            
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **  
**                                                                    **
***********************************************************************/


#include <vector>
#include "TClonesArray.h"

#include "BlockClasses.h"
#include "Utilities/ExRootAnalysis/interface/TSimpleArray.h"
#include "Utilities/ExRootAnalysis/interface/ExRootTreeBranch.h"

using namespace std;

class TriggerBit {

 public:

  TriggerBit(){}; 
  TriggerBit(const TriggerBit& tb);
  TriggerBit& operator=(const TriggerBit& tb);
  ~TriggerBit();

  void GetTrigCondition(const string& trigger_algorithm);
  void PrintTrigCondition(const string& LogName, const int i);
  bool GetResult(TClonesArray *branchElecTrig, TClonesArray *branchMuonTrig,
      TClonesArray *branchJetTrig, TClonesArray *branchTauJetTrig,
      TClonesArray *branchPhotonTrig,  TClonesArray *branchETmisTrig);
  vector<float> GetCuts(const vector<string> &Sequences);
  TSimpleArray<TRootJet> SubArrayBjets(TClonesArray *JET);
  TSimpleArray<TRootElectron> SubArrayIElec(TClonesArray *ELEC);
  TSimpleArray<TRootMuon> SubArrayIMuon(TClonesArray *MUON);

 private:
 
  vector<float> ElecValues;
  vector<float> IElecValues;
  vector<float> MuonValues;
  vector<float> IMuonValues;
  vector<float> JetValues;
  vector<float> BjetValues;
  vector<float> TauJetValues;
  vector<float> EtmisValues;
  vector<float> GammaValues;
  bool Result;
};


class TriggerTable {

 public:

  TriggerTable(); 
  ~TriggerTable() { list_of_trigger_bits.clear();};
  TriggerTable& operator=(TriggerTable& tt);
  TriggerTable(const TriggerTable& tt);

  void TriggerCardReader(const string& filename="data/trigger.dat");
  void PrintTriggerTable(const string& LogName);
  bool GetGlobalResult(TClonesArray *branchElecTrig, TClonesArray *branchMuonTrig,
      TClonesArray *branchJetTrig, TClonesArray *branchTauJetTrig,
      TClonesArray *branchPhotonTrig, TClonesArray *branchETmisTrig,ExRootTreeBranch *branchTrigger);

  void WriteResult();
    
 private:
  
  vector<TriggerBit> list_of_trigger_bits;
  bool has_been_evaluated;
  bool GlobalResult;

};

#endif
